@@ -1,7 +1,7 @@
 from robot.libraries.BuiltIn import BuiltIn
 import os
 from shutil import copyfile,rmtree
-
+from pkg_resources import resource_string
 
 class ScreenShotPlayer(object):
     ROBOT_LISTENER_API_VERSION = 2
@@ -27,64 +27,74 @@ class ScreenShotPlayer(object):
         else:
              ScreenShotPlayer.ScreenShotPlayerReportDir=os.path.join(ScreenShotPlayer.project_execution_dir,ScreenShotPlayer.whereToSaveReportDirRelativePath,'screenShotplayer')
 
-    
+
     @staticmethod
     def start_keyword(name, attributes):
-       
-        seleniumlib = BuiltIn().get_library_instance('SeleniumLibrary')
-        suite_source = BuiltIn().get_variable_value("${SUITE SOURCE}")
-        suite_name = suite_source.rsplit('\\')[-1].replace('.robot', '').strip()
-        seleniumlib.capture_page_screenshot('{}/{}/{}-{}.png'.format(ScreenShotPlayer.ScreenShotPlayerReportDir,suite_name, suite_name, ScreenShotPlayer.sc_index))
-        # print('{}/{}/{}-{}.png'.format(ScreenShotPlayer.ScreenShotPlayerReportDir,suite_name, suite_name, ScreenShotPlayer.sc_index))
-        ScreenShotPlayer.sc_index = ScreenShotPlayer.sc_index+1
+        # print(attributes)
+        if 'alert' in name.lower():return
+
+        try:
+            seleniumlib = BuiltIn().get_library_instance('SeleniumLibrary')
+            suite_source = BuiltIn().get_variable_value("${SUITE SOURCE}")
+            suite_name = suite_source.rsplit('\\')[-1].replace('.robot', '').strip()
+            seleniumlib.capture_page_screenshot('{}/{}/{}-{}.png'.format(ScreenShotPlayer.ScreenShotPlayerReportDir,suite_name, suite_name, ScreenShotPlayer.sc_index))
+            # print('{}/{}/{}-{}.png'.format(ScreenShotPlayer.ScreenShotPlayerReportDir,suite_name, suite_name, ScreenShotPlayer.sc_index))
+            ScreenShotPlayer.sc_index = ScreenShotPlayer.sc_index+1
+        except Exception as e:
+            print(e)
+         
       
 
     @staticmethod
     def end_keyword(name, attributes):
-        ScreenShotPlayer.start_keyword(name, attributes)
+        print(attributes['status'])
+        # pass
+        # ScreenShotPlayer.start_keyword(name, attributes)
       
     @staticmethod
     def getHTMLTemplate():
         return """<!DOCTYPE html>
 
-            <html>
+<html>
 
-            <head>
-                <link rel="stylesheet" href="style.css" />
-                <title>ScreenShotPlayer</title>
-                <script src="data.js"></script>
-                <script src="controller.js"></script>
-            
-            
-            </head>
-
-            <body onload="startTimer()">
-                <div style='position: absolute;border:2px solid red;width: 100%;height: 100%;'>
-                    <div id='sidebar'></div>
-                    <div id="imgcontainer">
-                        <img id="img" src="" />
-
-                        <div id="progressbar">
-                            <div id="myBar"></div>
-                        </div>
-                        <button id='btn_pause' type="button" onclick="pause()">Pause</button>
-                        <button id='btn_resume' type="button" onclick="resume()">Resume</button>
-                        <button id='btn_reset' type="button" onclick="reset()">Reset</button>
-                        <button id='next_frame' type="button" onclick="showNextFrame()">Next</button>
-                        <button id='prev_frame' type="button" onclick="showPrevFrame()">Prev</button>
-                        <span>
-                            <button id='speed_conroller' type="button" onclick="speedConroller(2)">+</button>
-                            <span id='interval_in_ms'>Nil</span>
-                            <button id='speed_conroller' type="button" onclick="speedConroller(0.5)">-</button>
-                        </span>
-                    </div>
-
-                </div>
+<head>
+    <link rel="stylesheet" href="style.css" />
+    <title>ScreenShotPlayer</title>
+    <script src="data.js"></script>
+    <script src="controller.js"></script>
 
 
-            </body>
+</head>
 
-            </html>"""
+<body onload="startTimer()">
+    <div class='grid'>
+        <div id='sidebar'></div>
+        <div id="imgcontainer">
+            <img id="img" src="" />
+
+            <div id="progressbar">
+                <div id="myBar"></div>
+            </div>
+            <div  class='controller_btn'>
+            <button id='btn_pause' class='btn' type="button" onclick="pause()">Pause</button>
+            <button id='btn_resume' class='btn' type="button" onclick="resume()">Resume</button>
+            <button id='btn_reset'   class='btn' type="button" onclick="reset()">Reset</button>
+            <button id='next_frame' class='btn'  type="button" onclick="showNextFrame()">Next</button>
+            <button id='prev_frame'  class='btn'  type="button" onclick="showPrevFrame()">Prev</button>
+            <span class='speed_conroller_grp'>
+                <button id='speed_conroller' type="button" onclick="speedConroller(2)">+</button>
+                <span id='interval_in_ms'>100</span>
+                <button id='speed_conroller' type="button" onclick="speedConroller(0.5)">-</button>
+            </span>
+            </div>
+        </div>
+
+    </div>
+
+
+</body>
+
+</html>"""
     
 
     @staticmethod
@@ -109,9 +119,11 @@ class ScreenShotPlayer(object):
             f.write('image_json_container1={}'.format(data))
         
 
-        resource_dir=__file__.replace('ScreenShotPlayer.py','resource')
-        copyfile(os.path.join(resource_dir,'style.css'),os.path.join(path_of_screen_shot_player,'style.css'))
-        copyfile(os.path.join(resource_dir,'controller.js'),os.path.join(path_of_screen_shot_player,'controller.js'))
+        # resource_dir=__file__.replace('ScreenShotPlayer.py','resource')
+        ScreenShotPlayer.createResourceCopy('style.css',path_of_screen_shot_player)
+        ScreenShotPlayer.createResourceCopy('controller.js',path_of_screen_shot_player)
+        # copyfile(os.path.join(resource_dir,'style.css'),os.path.join(path_of_screen_shot_player,'style.css'))
+        # copyfile(os.path.join(resource_dir,'controller.js'),os.path.join(path_of_screen_shot_player,'controller.js'))
 
 
         
@@ -131,7 +143,7 @@ class ScreenShotPlayer(object):
         for root, dirs, files in os.walk(ScreenShotPlayer.ScreenShotPlayerReportDir):
             if(root==ScreenShotPlayer.ScreenShotPlayerReportDir):
                 continue
-            image_container[str(key)] = [root, files]
+            image_container[str(key)] = [os.path.relpath(root,ScreenShotPlayer.ScreenShotPlayerReportDir), files]
             key = key+1
 
        
@@ -143,5 +155,11 @@ class ScreenShotPlayer(object):
         ScreenShotPlayer.generateScreenShotPlayerResource(str(image_container))
         
         print("[robot-screenshot-player]:report saved at location:\t{}/{}".format(ScreenShotPlayer.ScreenShotPlayerReportDir,'ScreenShotPlayer.html'))
+    
+    @staticmethod
+    def createResourceCopy(resource_name,path_where_to_create):
+        with open(os.path.join(path_where_to_create,resource_name),'w') as f:
+            f.write(str(resource_string("resource",resource_name).decode()))
+       
 
 
